@@ -30,6 +30,9 @@ abstract class bilde_renderer
 	var $embed_identifiers = null;
 
 	abstract function __construct($width, $height, $embed_identifiers = ""); // create the object
+	abstract static function renderer_supported();
+
+	abstract function html_embed_code($file_name, $attributes = null, $is_xsl = false);
 	abstract function render_image($output_file = null, $quality = 100);
 	abstract function resize_image($width, $height);
 	abstract function destroy_image();
@@ -57,56 +60,48 @@ abstract class bilde_renderer
 	public function setup_renderer($requested_renderer, $width, $height, $embed_identifiers = "")
 	{
 		bilde_renderer::setup_font_directory();
+		$available_renderers = array("PNG", "JPG", "GIF", "SWF", "SVG");
+		$fallback_renderer = "SVG";
+		$selected_renderer = null;
 
-		// Check if needed modules / extensions are available
-		$ming_available = extension_loaded("ming");
-		$gd_available = extension_loaded("gd"); // TODO: add check to see if dl() is permitted to load module
+		foreach($available_renderers as $this_renderer)
+		{
+			if(getenv(strtoupper($this_renderer) . "_DEBUG") != false)
+			{
+				eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
 
-		// Select a renderer
-		if(getenv("SVG_DEBUG") != false || $requested_renderer == "SVG")
-		{
-			$selected_renderer = "SVG";
-		}
-		else if($ming_available && (getenv("SWF_DEBUG") != false || $requested_renderer == "SWF"))
-		{
-			$selected_renderer = "SWF";
-		}
-		else if($gd_available)
-		{
-			if(getenv("JPG_DEBUG") != false || $requested_renderer == "JPG")
-			{
-				$selected_renderer = "JPG";
-			}
-			else
-			{
-				$selected_renderer = "PNG";
+				if($is_supported)
+				{
+					$requested_renderer = $this_renderer;
+					break;
+				}
 			}
 		}
-		else
+
+		foreach($available_renderers as $this_renderer)
 		{
-			$selected_renderer = "SVG";
+			if($requested_renderer == $this_renderer)
+			{
+				eval("\$is_supported = bilde_" . strtolower($this_renderer) . "_renderer::renderer_supported();");
+
+				if($is_supported)
+				{
+					$selected_renderer = $this_renderer;
+					break;
+				}
+			}
 		}
 
-		// Declare the selected renderer
-		switch($selected_renderer)
+		if(!in_array($selected_renderer, $available_renderers))
 		{
-			case "PNG":
-				$renderer = new bilde_png_renderer($width, $height, $embed_identifiers);
-				break;
-			case "JPG":
-				$renderer = new bilde_jpg_renderer($width, $height, $embed_identifiers);
-				break;
-			case "SWF":
-				$renderer = new bilde_swf_renderer($width, $height, $embed_identifiers);
-				break;
-			case "SVG":
-				$renderer = new bilde_svg_renderer($width, $height, $embed_identifiers);
-				break;
+			$selected_renderer = $fallback_renderer;
 		}
 
+		eval("\$renderer = new bilde_" . strtolower($selected_renderer) . "_renderer(\$width, \$height, \$embed_identifiers);");
+
 		return $renderer;
 	}
-	public function render_to_file($output_file = null, $quality = 0)
+	public function render_to_file($output_file = null, $quality = 100)
 	{
 		$output_file = str_replace("BILDE_EXTENSION", strtolower($this->get_renderer()), $output_file);
 		return $this->render_image($output_file, $quality);
@@ -121,7 +116,11 @@ abstract class bilde_renderer
 		// Setup directory for TTF Fonts
 		if(getenv("GDFONTPATH") == false)
 		{
-			if(defined("FONT_DIR"))
+			if(defined("CUSTOM_FONT_DIR"))
+			{
+				putenv("GDFONTPATH=" . CUSTOM_FONT_DIR);
+			}
+			else if(defined("FONT_DIR"))
 			{
 				putenv("GDFONTPATH=" . FONT_DIR);
 			}
@@ -135,6 +134,33 @@ abstract class bilde_renderer
 			}
 		}
 	}
+	public function find_default_ttf_font()
+	{
+		if(!defined("BILDE_DEFAULT_FONT"))
+		{
+			$default_font = false;
+			$possible_fonts = array(
+			"/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf",
+			"/usr/share/fonts/truetype/freefont/FreeSans.ttf",
+			"/usr/share/fonts/truetype/ttf-bitstream-vera/Vera.ttf",
+			"/usr/share/fonts/dejavu/DejaVuSans.ttf",
+			"/usr/share/fonts/liberation/LiberationSans-Regular.ttf"
+			);
+
+			foreach($possible_fonts as $font_file)
+			{
+				if(is_file($font_file))
+				{
+					$default_font = $font_file;
+					break;
+				}
+			}
+
+			define("BILDE_DEFAULT_FONT", $default_font);
+		}
+
+		return BILDE_DEFAULT_FONT;
+	}
 	public function get_renderer()
 	{
 		return $this->renderer;
@@ -180,7 +206,7 @@ abstract class bilde_renderer
 
 			if($predefined_string)
 			{
-				$box_array = imagettfbbox($font_size, 0, $font_type, "AZ@![]()@|_");
+				$box_array = imagettfbbox($font_size, 0, $font_type, "AZ@![]()@|_qy");
 			}
 
 			$box_height = $box_array[1] - $box_array[7];
@@ -195,6 +221,20 @@ abstract class bilde_renderer
 		// Width x Height
 		return array($box_width, $box_height);
 	}
+	public function draw_arrow($tip_x1, $tip_y1, $tail_x1, $tail_y1, $background_color)
+	{
+		// TODO: Allow better support when arrow is running horizontally or on an angle instead of just vertical
+		$arrow_length = sqrt(pow(($tail_x1 - $tip_x1), 2) + pow(($tail_y1 - $tip_y1), 2));
+		$arrow_length_half = $arrow_length / 2;
+
+		$arrow_points = array(
+		$tip_x1, $tip_y1,
+		$tail_x1 + $arrow_length_half, $tail_y1,
+		$tail_x1 - $arrow_length_half, $tail_y1
+		);
+
+		$this->draw_polygon($arrow_points, $background_color);
+	}
 	protected function text_string_width($text_string, $font_type, $font_size)
 	{
 		$dimensions = $this->text_string_dimensions($text_string, $font_type, $font_size);
