@@ -29,7 +29,7 @@ abstract class pts_Graph
 	var $graph_attr_height = 300; // Graph height
 	var $graph_attr_big_border = false; // Border around graph or not
 
-	var $graph_left_start = 20; // Distance in px to start graph from left side
+	var $graph_left_start = 10; // Distance in px to start graph from left side
 	var $graph_left_end_opp = 10; // Distance in px to end graph from right side
 	var $graph_top_start = 62; // Distance in px to start graph from top side
 	var $graph_top_end_opp = 22; // Distance in px to end graph from bottom side
@@ -61,8 +61,6 @@ abstract class pts_Graph
 	var $graph_version = "";
 	var $graph_proportion = "";
 
-	// CHANGE DIRECTORY FOR TTF FONT LOCATION INSIDE __construct FUNCTION
-
 	// Not user-friendly changes below this line
 	var $graph_body_image = false;
 	var $graph_hide_identifiers = false;
@@ -78,10 +76,10 @@ abstract class pts_Graph
 	var $graph_data = array();
 	var $graph_data_raw = array();
 	var $graph_data_title = array();
+	var $graph_sub_titles = array();
 	var $graph_color_paint_index = -1;
 	var $graph_identifiers;
 	var $graph_title;
-	var $graph_sub_title;
 	var $graph_y_title;
 	var $graph_y_title_hide = false;
 	var $graph_top_end;
@@ -89,15 +87,46 @@ abstract class pts_Graph
 
 	var $graph_internal_identifiers = array();
 
+	// Internal Switches
+	// var $graph_format_heading = "NORMAL";
+
 	public function __construct($title, $sub_title, $y_axis_title)
 	{
 		$this->graph_title = $title;
-		$this->graph_sub_title = $sub_title;
 		$this->graph_y_title = $y_axis_title;
 
+		if(!empty($sub_title))
+		{
+			$this->addSubTitle($sub_title);
+		}
+
 		$this->update_graph_dimensions(-1, -1, true);
+
+		if(empty($this->graph_font))
+		{
+			$default_font = bilde_renderer::find_default_ttf_font();
+
+			if($default_font == false)
+			{
+				$this->requestRenderer("SVG");
+				$font_type = null;
+			}
+			else
+			{
+				$font_type = basename($default_font);
+
+				if($default_font != $font_type && !defined("CUSTOM_FONT_DIR"))
+				{
+					$font_path = substr($default_font, 0, 0 - (strlen($font_type)));
+					define("CUSTOM_FONT_DIR", $font_path);
+					bilde_renderer::setup_font_directory();
+				}
+			}
+
+			$this->graph_font = $font_type;
+		}
 	}
-	public function setRenderer($renderer)
+	public function requestRenderer($renderer)
 	{
 		$this->graph_renderer = $renderer;
 	}
@@ -127,12 +156,7 @@ abstract class pts_Graph
 	}
 	public function loadGraphProportion($data)
 	{
-		if($data == "LIB")
-		{
-			$this->graph_proportion = "Fewer Are Better";
-		}
-		//else if($data == "HIB")
-		//	$this->graph_proportion = "More Is Better";
+		$this->graph_proportion = $data;
 	}
 	public function loadGraphData($data_array)
 	{
@@ -168,40 +192,14 @@ abstract class pts_Graph
 			$this->graph_body_image = $img;
 		}
 	}
-	public function renderGraph()
+	public function addSubTitle($sub_title)
 	{
-		$this->graph_maximum_value = $this->maximum_graph_value();
+		$sub_titles = array_map("trim", explode("|", $sub_title));
 
-		// Make room for tick markings, left hand side
-		if($this->graph_value_type == "NUMERICAL")
+		foreach($sub_titles as $sub_title)
 		{
-			$this->graph_left_start += $this->text_string_width($this->graph_maximum_value, $this->graph_font, $this->graph_font_size_tick_mark) + 2;
+			array_push($this->graph_sub_titles, $sub_title);
 		}
-
-		if($this->graph_hide_identifiers == true)
-		{
-			$this->graph_top_end += $this->graph_top_end_opp / 2;
-		}
-
-		// Do the actual work
-		$this->render_graph_pre_init();
-		$this->render_graph_init();
-		$this->render_graph_base();
-
-		if(!$this->graph_hide_identifiers)
-		{
-			$this->render_graph_identifiers();
-		}
-
-		if($this->graph_value_type == "NUMERICAL")
-		{
-			$this->render_graph_value_ticks();
-		}
-
-		$this->render_graph_key();
-		$this->render_graph_result();
-		$this->render_graph_watermark();
-		$this->return_graph_image();
 	}
 	public function addInternalIdentifier($identifier, $value)
 	{
@@ -211,6 +209,18 @@ abstract class pts_Graph
 	{
 		$this->graph_output = $file;
 	}
+	public function htmlEmbedCode($file, $width, $height)
+	{
+		$attributes = array();
+
+		if($this->graph_renderer == "SWF")
+		{
+			$attributes["width"] = $width;
+			$attributes["height"] = $height;
+		}
+
+		return $this->graph_image->html_embed_code($file, $attributes, true);
+	}
 	public function graphWidth()
 	{
 		return $this->graph_attr_width;
@@ -322,6 +332,43 @@ abstract class pts_Graph
 	// Render Functions
 	//
 
+
+	public function renderGraph()
+	{
+		$this->graph_maximum_value = $this->maximum_graph_value();
+
+		// Make room for tick markings, left hand side
+		if($this->graph_value_type == "NUMERICAL")
+		{
+			$this->graph_left_start += $this->text_string_width($this->graph_maximum_value, $this->graph_font, $this->graph_font_size_tick_mark) + 2;
+		}
+
+		if($this->graph_hide_identifiers == true)
+		{
+			$this->graph_top_end += $this->graph_top_end_opp / 2;
+		}
+
+		// Do the actual work
+		$this->render_graph_pre_init();
+		$this->render_graph_init();
+		$this->render_graph_base();
+		$this->render_graph_heading();
+
+		if(!$this->graph_hide_identifiers)
+		{
+			$this->render_graph_identifiers();
+		}
+
+		if($this->graph_value_type == "NUMERICAL")
+		{
+			$this->render_graph_value_ticks();
+		}
+
+		$this->render_graph_key();
+		$this->render_graph_result();
+		$this->render_graph_watermark();
+		$this->return_graph_image();
+	}
 	protected function render_graph_pre_init()
 	{
 		return;
@@ -330,7 +377,7 @@ abstract class pts_Graph
 	{
 		$this->update_graph_dimensions();
 		$this->graph_image = bilde_renderer::setup_renderer($this->graph_renderer, $this->graph_attr_width, $this->graph_attr_height, $this->graph_internal_identifiers);
-		$this->setRenderer($this->graph_image->get_renderer());
+		$this->requestRenderer($this->graph_image->get_renderer());
 
 		// Initalize Colors
 		$this->graph_color_notches = $this->graph_image->convert_hex_to_type($this->graph_color_notches);
@@ -356,12 +403,29 @@ abstract class pts_Graph
 			$this->graph_image->draw_rectangle_border(0, 0, $this->graph_attr_width - 1, $this->graph_attr_height - 1, $this->graph_color_border);
 		}
 	}
+	protected function render_graph_heading()
+	{
+		// Default to NORMAL
+		$this->graph_image->write_text_center($this->graph_title, $this->graph_font, $this->graph_font_size_heading, $this->graph_color_main_headers, $this->graph_left_start, 3, $this->graph_left_end, 3);
+
+		for($i = 0; $i < count($this->graph_sub_titles); $i++)
+		{
+			$this->graph_image->write_text_center($this->graph_sub_titles[$i], $this->graph_font, $this->graph_font_size_sub_heading, $this->graph_color_main_headers, $this->graph_left_start, (29 + ($i * 18)), $this->graph_left_end, (29 + ($i * 18)), false, true);
+		}
+
+		$this->graph_image->write_text_right($this->graph_version, $this->graph_font, 7, $this->graph_color_body_light, $this->graph_left_end, $this->graph_top_start - 9, $this->graph_left_end, $this->graph_top_start - 9);
+	}
 	protected function render_graph_base()
 	{
 		if(count($this->graph_data_title) > 1 || $this->graph_show_key == true)
 		{
 			$num_key_lines = ceil(count($this->graph_data_title) / 4);
-			$this->graph_top_start = $this->graph_top_start + 8 + ($num_key_lines * 11);
+			$this->graph_top_start += 8 + ($num_key_lines * 11);
+		}
+
+		if(($sub_title_count = count($this->graph_sub_titles)) > 1)
+		{
+			$this->graph_top_start += (($sub_title_count - 1) * 14);
 		}
 
 		$this->graph_image->draw_rectangle($this->graph_left_start, $this->graph_top_start, $this->graph_left_end, $this->graph_top_end, $this->graph_color_body);
@@ -372,26 +436,41 @@ abstract class pts_Graph
 			$this->graph_image->image_copy_merge($this->graph_body_image, $this->graph_left_start + (($this->graph_left_end - $this->graph_left_start) / 2) - imagesx($this->graph_body_image) / 2, $this->graph_top_start + (($this->graph_top_end - $this->graph_top_start) / 2) - imagesy($this->graph_body_image) / 2);
 		}
 
-		// Text
-		$this->graph_image->write_text_right($this->graph_version, $this->graph_font, 7, $this->graph_color_body_light, $this->graph_left_end, $this->graph_top_start - 9, $this->graph_left_end, $this->graph_top_start - 9);
-		$this->graph_image->write_text_center($this->graph_title, $this->graph_font, $this->graph_font_size_heading, $this->graph_color_main_headers, $this->graph_left_start, 3, $this->graph_left_end, 4);
-		$this->graph_image->write_text_center($this->graph_sub_title, $this->graph_font, $this->graph_font_size_sub_heading, $this->graph_color_main_headers, $this->graph_left_start, 30, $this->graph_left_end, 26, false, true);
-
 		if(!empty($this->graph_y_title) && !$this->graph_y_title_hide)
 		{
 			$str = $this->graph_y_title;
+			$offset = 0;
 
 			if(!empty($this->graph_proportion))
 			{
-				if(!empty($str))
+				$proportion = null;
+ 
+				switch($this->graph_proportion)
 				{
-					$str .= ", ";
+					case "LIB":
+						$proportion = "Fewer Are Better";
+						$offset += 12;
+						$this->graph_image->draw_arrow($this->graph_left_start + 5, $this->graph_top_start - 4, $this->graph_left_start + 5, $this->graph_top_start - 11, $this->graph_color_main_headers);
+						break;
+					case "HIB":
+						//$proportion = "Higher Is Better";
+						$offset += 12;
+						$this->graph_image->draw_arrow($this->graph_left_start + 5, $this->graph_top_start - 11, $this->graph_left_start + 5, $this->graph_top_start - 4, $this->graph_color_main_headers);
+						break;
 				}
 
-				$str .= $this->graph_proportion;
+				if($proportion != null)
+				{
+					if(!empty($str))
+					{
+						$str .= ", ";
+					}
+
+					$str .= $proportion;
+				}
 			}
 
-			$this->graph_image->write_text_left($str, $this->graph_font, 7, $this->graph_color_main_headers, $this->graph_left_start, $this->graph_top_start - 9, $this->graph_left_start, $this->graph_top_start - 9);
+			$this->graph_image->write_text_left($str, $this->graph_font, 7, $this->graph_color_main_headers, $this->graph_left_start + $offset, $this->graph_top_start - 9, $this->graph_left_start + $offset, $this->graph_top_start - 9);
 		}
 	}
 	protected function render_graph_value_ticks()
