@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,9 +22,12 @@
 
 class download_test_files implements pts_option_interface
 {
+	public static function required_function_sets()
+	{
+		return array("install");
+	}
 	public static function run($r)
 	{
-		pts_load_function_set("install");
 		$test = $r[0];
 
 		if(empty($test))
@@ -37,7 +40,7 @@ class download_test_files implements pts_option_interface
 
 			if(count($tests) == 0)
 			{
-				echo "\n" . $test . " isn't recognized.\n";
+				echo "\n" . $test . " is not recognized.\n";
 			}
 			else
 			{
