@@ -27,7 +27,8 @@ class list_saved_results implements pts_option_interface
 		echo pts_string_header("Phoronix Test Suite - Saved Results");
 		foreach(glob(SAVE_RESULTS_DIR . "*/composite.xml") as $saved_results_file)
 		{
-			echo new pts_test_results_details($saved_results_file) . "\n";
+			$tr = new pts_test_result_details($saved_results_file);
+			echo $tr->show_basic_details() . "\n";
 		}
 		echo "\n";
 	}
