@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,9 +22,12 @@
 
 class make_download_cache implements pts_option_interface
 {
+	public static function required_function_sets()
+	{
+		return array("misc");
+	}
 	public static function run($r)
 	{
-		pts_load_function_set("install");
 		echo pts_string_header("Phoronix Test Suite - Generating Download Cache");
 		pts_generate_download_cache();
 		echo "\n";
