@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,13 +24,13 @@ class result_info implements pts_option_interface
 {
 	public static function run($r)
 	{
-		if(is_file(($saved_results_file = SAVE_RESULTS_DIR . $r[0] . "/composite.xml")))
+		if(($file = pts_find_result_file($r[0])) != false)
 		{
-			echo new pts_test_result_info_details($saved_results_file);
+			echo new pts_test_result_details(file_get_contents($file), $r[0]);
 		}
 		else
 		{
-			echo "\n" . $r[0] . " isn't a valid results file.\n";
+			echo "\n" . $r[0] . " is not a valid results file.\n";
 		}
 		echo "\n";
 	}
