@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008, Phoronix Media
-	Copyright (C) 2008, Michael Larabel
+	Copyright (C) 2008 - 2009, Phoronix Media
+	Copyright (C) 2008 - 2009, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,26 +22,30 @@
 
 class upload_result implements pts_option_interface
 {
+	public static function required_function_sets()
+	{
+		return array("run");
+	}
 	public static function run($r)
 	{
-		pts_load_function_set("run");
-
-		$USE_FILE = pts_find_result_file($r[0], false);
-
-		if($USE_FILE == false)
+		if(($use_file = pts_find_result_file($r[0], false)) == false)
 		{
-			echo "\nThis result doesn't exist.\n";
+			echo "\nThis result does not exist.\n";
 		}
 		else
 		{
-			$tags_input = pts_promt_user_tags();
-			echo "\n";
+			if(!pts_is_assignment("AUTOMATED_MODE"))
+			{
+				$tags_input = pts_promt_user_tags();
+				echo "\n";
+			}
 
-			$upload_url = pts_global_upload_result($USE_FILE, $tags_input);
+			$upload_url = pts_global_upload_result($use_file, $tags_input);
 
 			if(!empty($upload_url))
 			{
-				echo "Results Uploaded To: " . $upload_url . "\n\n";
+				echo "\nResults Uploaded To: " . $upload_url . "\n\n";
+				pts_set_assignment_next("PREV_GLOBAL_UPLOAD_URL", $upload_url);
 				pts_module_process("__event_global_upload", $upload_url);
 			}
 			else
