@@ -2,7 +2,7 @@
 
 # Phoronix Test Suite
 # URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-# Copyright (C) 2008, Phoronix Media
+# Copyright (C) 2008 - 2009, Phoronix Media
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,22 +17,25 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-if [ pts`which xdg-open` != pts ]
+if [ "`which x-www-browser`" ] && [ "`which konqueror`" ]
+then
+	x-www-browser "$1"
+elif [ "`which xdg-open`" ]
 then
 	xdg-open "$1"
-elif [ pts`which epiphany` != pts ]
+elif [ "`which epiphany`" ]
 then
 	epiphany "$1"
-elif [ pts`which firefox` != pts ]
+elif [ "`which firefox`" ]
 then
 	firefox "$1"
-elif [ pts`which mozilla` != pts ]
+elif [ "`which mozilla`" ]
 then
 	mozilla "$1"
-elif [ pts`which open` != pts ]
+elif [ "`which open`" ]
 then
 	open "$1"
 else
-	"URL: $1"
+	echo "URL: $1"
 fi
 
