@@ -13,7 +13,10 @@ mv -f demos/ ~/.smokinguns/smokinguns/
 
 echo "#!/bin/sh
 cd Smokin\'\ Guns/
-
-./smokinguns.x86 \$@ > \$LOG_FILE 2>&1
+rm -f libopenal.so.0
+rm -f libGL.so
+[ -r /usr/lib/libGL.so.1 -a ! -r /usr/lib/libGL.so ] && ln -fs /usr/lib/libGL.so.1 libGL.so
+[ -r /usr/lib/libopenal.so.1 -a ! -r /usr/lib/libopenal.so.0 ] && ln -fs /usr/lib/libopenal.so.1 libopenal.so.0
+LD_LIBRARY_PATH=. ./smokinguns.x86 \$@ > \$LOG_FILE 2>&1
 cat \$LOG_FILE | grep fps" > smokin-guns
 chmod +x smokin-guns
